@@ -19,9 +19,7 @@ class Member3D():
     __plt = None
 
 #%%
-    def __init__(self, name, i_node, j_node, E, G, Iy, Iz, J, A, auxNode=None, 
-                 LoadCombos={'Combo 1':LoadCombo('Combo 1', 
-                             factors={'Case 1':1.0})},
+    def __init__(self, name, i_node, j_node, E, G, Iy, Iz, J, A, model, auxNode=None,
                  tension_only=False, comp_only=False):
         '''
         Initializes a new member.
@@ -43,7 +41,6 @@ class Member3D():
         self.SegmentsY = [] # A list of mathematically continuous beam segments for y-bending
         self.SegmentsX = [] # A list of mathematically continuous beam segments for torsion
         self.Releases = [False, False, False, False, False, False, False, False, False, False, False, False]
-        self.LoadCombos = LoadCombos # The dictionary of load combinations in the model this member belongs to
         self.tension_only = tension_only # Indicates whether the member is tension-only
         self.comp_only = comp_only # Indicates whether the member is compression-only
 
@@ -57,6 +54,9 @@ class Member3D():
         # calculations for any given load combination.
         self.__solved_combo = None # The current solved load combination
 
+        # Members need a link to the model they belong to
+        self.model = model
+
 #%%
     def L(self):
         '''
@@ -247,7 +247,7 @@ class Member3D():
         fer = zeros((12,1))
 
         # Get the requested load combination
-        combo = self.LoadCombos[combo_name]
+        combo = self.model.LoadCombos[combo_name]
 
         # Loop through each load case and factor in the load combination
         for case, factor in combo.factors.items():
@@ -348,18 +348,23 @@ class Member3D():
         '''
         
         # Calculate and return the member's local end force vector
-        return add(matmul(self.k(), self.d(combo_name)), self.fer(combo_name))
+        if self.model.solution == 'P-Delta':
+            # Back-calculate the axial force on the member from the axial strain
+            P = (self.d(combo_name)[6, 0] - self.d(combo_name)[0, 0])*self.A*self.E/self.L()
+            return add(matmul(add(self.k(), self.kg(P)), self.d(combo_name)), self.fer(combo_name))
+        else:
+            return add(matmul(self.k(), self.d(combo_name)), self.fer(combo_name))
 
 #%%
     def d(self, combo_name='Combo 1'):
-        '''
+        """
         Returns the member's local displacement vector.
 
         Parameters
         ----------
         combo_name : string
             The name of the load combination to construct the displacement vector for (not the load combination itself).
-        '''
+        """
         
         # Calculate and return the local displacement vector
         return matmul(self.T(), self.D(combo_name))
@@ -506,7 +511,7 @@ class Member3D():
 
 #%%
     def D(self, combo_name='Combo 1'):
-        '''
+        """
         Returns the member's global displacement vector.
 
         Parameters
@@ -514,7 +519,7 @@ class Member3D():
         combo_name : string
             The name of the load combination to construct the global
             displacement vector for (not the load combination itelf).
-        '''
+        """
         
         # Initialize the displacement vector
         D = zeros((12, 1))
@@ -541,12 +546,8 @@ class Member3D():
         return D
 
 #%%
-    def Shear(self, Direction, x, combo_name='Combo 1'):
-        warnings.warn('`Shear` will be replaced with `shear` in a future version of PyNite.', FutureWarning)
-        return self.shear(Direction, x, combo_name)
-
     def shear(self, Direction, x, combo_name='Combo 1'):
-        '''
+        """
         Returns the shear at a point along the member's length.
         
         Parameters
@@ -559,12 +560,12 @@ class Member3D():
             The location at which to find the shear.
         combo_name : string
             The name of the load combination to get the results for (not the combination itself).
-        '''
+        """
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
 
         # Check which direction is of interest
         if Direction == 'Fy':
@@ -592,12 +593,8 @@ class Member3D():
                 return self.SegmentsY[lastIndex].Shear(x - self.SegmentsY[lastIndex].x1)
             
 #%%
-    def MaxShear(self, Direction, combo_name='Combo 1'):
-        warnings.warn('`MaxShear` will be replaced with `max_shear` in a future version of PyNite.', FutureWarning)
-        return self.max_shear(Direction, combo_name)
-
     def max_shear(self, Direction, combo_name='Combo 1'):
-        '''
+        """
         Returns the maximum shear in the member for the given direction
         
         Parameters
@@ -608,12 +605,12 @@ class Member3D():
                 'Fz' = Shear acting on the local z-axis
         combo_name : string
             The name of the load combination to get the results for (not the combination itself).
-        '''
+        """
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
         
         if Direction == 'Fy':
             
@@ -638,12 +635,8 @@ class Member3D():
         return Vmax
     
 #%%
-    def MinShear(self, Direction, combo_name='Combo 1'):
-        warnings.warn('`MinShear` will be replaced with `min_shear` in a future version of PyNite.', FutureWarning)
-        return self.min_shear(Direction, combo_name)
-
     def min_shear(self, Direction, combo_name='Combo 1'):
-        '''
+        """
         Returns the minimum shear in the member for the given direction
         
         Parameters
@@ -654,12 +647,12 @@ class Member3D():
                 'Fz' = Shear acting on the local z-axis
         combo_name : string
             The name of the load combination to get the results for (not the load combination itself).
-        '''
+        """
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]   
+            self.__solved_combo = self.model.LoadCombos[combo_name]   
         
         if Direction == 'Fy':
             
@@ -684,10 +677,6 @@ class Member3D():
         return Vmin
     
 #%%
-    def PlotShear(self, Direction, combo_name='Combo 1'):
-        warnings.warn('`PlotShear` will be replaced with `plot_shear` in a future version of PyNite.', FutureWarning)
-        self.plot_shear(Direction, combo_name)
-
     def plot_shear(self, Direction, combo_name='Combo 1'):
         '''
         Plots the shear diagram for the member
@@ -703,7 +692,7 @@ class Member3D():
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
         
         # Import 'pyplot' if not already done
         if Member3D.__plt is None:
@@ -729,12 +718,8 @@ class Member3D():
         Member3D.__plt.show()    
         
 #%%
-    def Moment(self, Direction, x, combo_name='Combo 1'):
-        warnings.warn('`Moment` will be replaced with `moment` in a future version of PyNite.', FutureWarning)
-        return self.moment(Direction, x, combo_name)
-
     def moment(self, Direction, x, combo_name='Combo 1'):
-        '''
+        """
         Returns the moment at a point along the member's length
         
         Parameters
@@ -747,12 +732,12 @@ class Member3D():
             The location at which to find the moment.
         combo_name : string
             The name of the load combination to get the results for (not the load combination itself).
-        '''
+        """
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
         
         # Check which axis is of interest
         if Direction == 'My':
@@ -787,12 +772,8 @@ class Member3D():
             raise ValueError(f"Direction must be 'My' or 'Mz'. {Direction} was given.")
             
 #%%
-    def MaxMoment(self, Direction, combo_name='Combo 1'):
-        warnings.warn('`MaxMoment` will be replaced with `max_moment` in a future version of PyNite.', FutureWarning)
-        return self.max_moment(Direction, combo_name)
-
     def max_moment(self, Direction, combo_name='Combo 1'):
-        '''
+        """
         Returns the maximum moment in the member for the given direction.
         
         Parameters
@@ -803,12 +784,12 @@ class Member3D():
                 'Mz' = Moment about the local z-axis.
         combo_name : string
             The name of the load combination to get the results for (not the combination itself).
-        '''
+        """
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
         
         if Direction == 'Mz':
             
@@ -833,12 +814,8 @@ class Member3D():
         return Mmax
 
 #%%
-    def MinMoment(self, Direction, combo_name='Combo 1'):
-        warnings.warn('`MinMoment` will be replaced with `min_moment` in a future version of PyNite.', FutureWarning)
-        return self.min_moment(Direction, combo_name)
-
     def min_moment(self, Direction, combo_name='Combo 1'):
-        '''
+        """
         Returns the minimum moment in the member for the given direction
         
         Parameters
@@ -849,12 +826,12 @@ class Member3D():
                 'Mz' = Moment about the local z-axis.
         combo_name : string
             The name of the load combination to get the results for (not the load combination itself).
-        '''
+        """
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)   
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
         
         if Direction == 'Mz':
             
@@ -879,10 +856,6 @@ class Member3D():
         return Mmin
 
 #%%
-    def PlotMoment(self, Direction, combo_name='Combo 1'):
-        warnings.warn('`PlotMoment` will be replaced with `plot_moment` in a future version of PyNite.', FutureWarning)
-        self.plot_moment(Direction, combo_name)
-
     def plot_moment(self, Direction, combo_name='Combo 1'):
         '''
         Plots the moment diagram for the member
@@ -898,7 +871,7 @@ class Member3D():
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
                 
         # Import 'pyplot' if not already done
         if Member3D.__plt is None:
@@ -925,12 +898,8 @@ class Member3D():
         Member3D.__plt.show()
        
 #%%
-    def Torsion(self, x, combo_name='Combo 1'):
-        warnings.warn('`Torsion` will be replaced with `torque` in a future version of PyNite.', FutureWarning)
-        return self.torque(x, combo_name)
-
     def torque(self, x, combo_name='Combo 1'):
-        '''
+        """
         Returns the torsional moment at a point along the member's length
         
         Parameters
@@ -939,12 +908,12 @@ class Member3D():
             The location at which to find the torque
         combo_name : string
             The name of the load combination to get the results for (not the load combination itself).
-        '''
+        """
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
             
         # Check which segment 'x' falls on
         for segment in self.SegmentsX:
@@ -956,10 +925,6 @@ class Member3D():
                 return self.SegmentsX[lastIndex].Torsion()
 
 #%%
-    def MaxTorsion(self, combo_name='Combo 1'):
-        warnings.warn('`MaxTorsion` will be replaced with `max_torque` in a future version of PyNite.', FutureWarning)
-        return self.max_torque(combo_name)
-
     def max_torque(self, combo_name='Combo 1'):
         '''
         Returns the maximum torsional moment in the member.
@@ -973,7 +938,7 @@ class Member3D():
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]       
+            self.__solved_combo = self.model.LoadCombos[combo_name]       
         
         Tmax = self.SegmentsX[0].Torsion()   
         
@@ -986,24 +951,20 @@ class Member3D():
         return Tmax
     
 #%%
-    def MinTorsion(self, combo_name='Combo 1'):
-        warnings.warn('`MinTorsion` will be replaced with `min_torque` in a future version of PyNite.', FutureWarning)
-        return self.min_torque(combo_name)
-
     def min_torque(self, combo_name='Combo 1'):
-        '''
+        """
         Returns the minimum torsional moment in the member.
 
         Parameters
         ----------
         combo_name : string
             The name of the load combination to get the results for (not the load combination itself).
-        '''
+        """
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
         
         Tmin = self.SegmentsX[0].Torsion()
             
@@ -1016,10 +977,6 @@ class Member3D():
         return Tmin
 
 #%%
-    def PlotTorsion(self, combo_name='Combo 1'):
-        warnings.warn('`PlotTorsion` will be replaced with `plot_torque` in a future version of PyNite.', FutureWarning)
-        self.plot_torque(combo_name)
-
     def plot_torque(self, combo_name='Combo 1'):
         '''
         Plots the axial force diagram for the member.
@@ -1033,7 +990,7 @@ class Member3D():
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
         
         # Import 'pyplot' if not already done
         if Member3D.__plt is None:
@@ -1059,12 +1016,8 @@ class Member3D():
         Member3D.__plt.show()   
         
 #%%
-    def Axial(self, x, combo_name='Combo 1'):
-        warnings.warn('`Axial` will be replaced with `axial` in a future version of PyNite.', FutureWarning)
-        return self.axial(x, combo_name)
-
     def axial(self, x, combo_name='Combo 1'):
-        '''
+        """
         Returns the axial force at a point along the member's length.
         
         Parameters
@@ -1073,12 +1026,12 @@ class Member3D():
             The location at which to find the axial force.
         combo_name : string
             The name of the load combination to get the results for (not the load combination itself).
-        '''
+        """
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
             
         # Check which segment 'x' falls on
         for segment in self.SegmentsZ:
@@ -1090,10 +1043,6 @@ class Member3D():
                 return self.SegmentsZ[lastIndex].axial(x - self.SegmentsZ[lastIndex].x1)
 
 #%%
-    def MaxAxial(self, combo_name='Combo 1'):
-        warnings.warn('`MaxAxial` will be replaced with `max_axial` in a future version of PyNite.', FutureWarning)
-        return self.max_axial(combo_name)
-
     def max_axial(self, combo_name='Combo 1'):
         '''
         Returns the maximum axial force in the member
@@ -1107,7 +1056,7 @@ class Member3D():
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
         
         Pmax = self.SegmentsZ[0].axial(0)   
         
@@ -1120,10 +1069,6 @@ class Member3D():
         return Pmax
     
 #%%
-    def MinAxial(self, combo_name='Combo 1'):
-        warnings.warn('`MinAxial` will be replaced with `min_axial` in a future version of PyNite.', FutureWarning)
-        return self.min_axial(combo_name)
-
     def min_axial(self, combo_name='Combo 1'):
         '''
         Returns the minimum axial force in the member.
@@ -1137,7 +1082,7 @@ class Member3D():
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
         
         Pmin = self.SegmentsZ[0].axial(0)
             
@@ -1150,10 +1095,6 @@ class Member3D():
         return Pmin
     
 #%%
-    def PlotAxial(self, combo_name='Combo 1'):
-        warnings.warn('`PlotAxial` will be replaced with `plot_axial` in a future version of PyNite.', FutureWarning)
-        self.plot_axial(combo_name)
-
     def plot_axial(self, combo_name='Combo 1'):
         '''
         Plots the axial force diagram for the member.
@@ -1167,7 +1108,7 @@ class Member3D():
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
         
         # Import 'pyplot' if not already done
         if Member3D.__plt is None:
@@ -1193,12 +1134,8 @@ class Member3D():
         Member3D.__plt.show()    
                         
 #%%
-    def Deflection(self, Direction, x, combo_name='Combo 1'):
-        warnings.warn('`Deflection` will be replaced with `deflection` in a future version of PyNite.', FutureWarning)
-        return self.deflection(Direction, x, combo_name)
-
     def deflection(self, Direction, x, combo_name='Combo 1'):
-        '''
+        """
         Returns the deflection at a point along the member's length.
         
         Parameters
@@ -1212,12 +1149,12 @@ class Member3D():
             The location at which to find the deflection.
         combo_name : string
             The name of the load combination to get the results for (not the load combination itself).
-        '''
+        """
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
         
         # Check which axis is of interest
         if Direction == 'dx':
@@ -1261,12 +1198,8 @@ class Member3D():
                 return self.SegmentsY[lastIndex].deflection(x - self.SegmentsY[lastIndex].x1) 
 
 #%%
-    def MaxDeflection(self, Direction, combo_name='Combo 1'):
-        warnings.warn('`MaxDeflection` will be replaced with `max_deflection` in a future version of PyNite.', FutureWarning)
-        return self.max_deflection(Direction, combo_name)
-
     def max_deflection(self, Direction, combo_name='Combo 1'):
-        '''
+        """
         Returns the maximum deflection in the member.
         
         Parameters
@@ -1275,12 +1208,12 @@ class Member3D():
             The direction in which to find the maximum deflection.
         combo_name : string
             The name of the load combination to get the results for (not the load combination itself).
-        '''
+        """
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
         
         # Initialize the maximum deflection
         dmax = self.deflection(Direction, 0, combo_name)
@@ -1295,12 +1228,8 @@ class Member3D():
         return dmax
     
 #%%
-    def MinDeflection(self, Direction, combo_name='Combo 1'):
-        warnings.warn('`MinDeflection` will be replaced with `min_deflection` in a future version of PyNite.', FutureWarning)
-        return self.min_deflection(Direction, combo_name)
-
     def min_deflection(self, Direction, combo_name='Combo 1'):
-        '''
+        """
         Returns the minimum deflection in the member.
         
         Parameters
@@ -1309,12 +1238,12 @@ class Member3D():
             The direction in which to find the minimum deflection.
         combo_name : string
             The name of the load combination to get the results for (not the load combination itself).
-        '''
+        """
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
         
         # Initialize the minimum deflection
         dmin = self.deflection(Direction, 0, combo_name)
@@ -1329,12 +1258,8 @@ class Member3D():
         return dmin
               
 #%%
-    def PlotDeflection(self, Direction, combo_name='Combo 1'):
-        warnings.warn('`PlotDeflection` will be replaced with `plot_deflection` in a future version of PyNite.', FutureWarning)
-        self.plot_deflection(Direction, combo_name)
-
     def plot_deflection(self, Direction, combo_name='Combo 1'):
-        '''
+        """
         Plots the deflection diagram for the member
         
         Parameters
@@ -1343,12 +1268,12 @@ class Member3D():
             The direction in which to plot the deflection.
         combo_name : string
             The name of the load combination to get the results for (not the load combination itself).
-        '''
+        """
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
                 
         # Import 'pyplot' if not already done
         if Member3D.__plt is None:
@@ -1375,12 +1300,8 @@ class Member3D():
         Member3D.__plt.show()
     
 #%%
-    def RelativeDeflection(self, Direction, x, combo_name='Combo 1'):
-        warnings.warn('`RelativeDeflection` will be replaced with `rel_deflection` in a future version of PyNite.', FutureWarning)
-        return self.rel_deflection(Direction, x, combo_name)
-
     def rel_deflection(self, Direction, x, combo_name='Combo 1'):
-        '''
+        """
         Returns the relative deflection at a point along the member's length
         
         Parameters
@@ -1393,14 +1314,14 @@ class Member3D():
             The location at which to find the relative deflection
         combo_name : string
             The name of the load combination to get the results for (not the combination itself).
-        '''
-        
+        """
+
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
         
-        d = self.d(self.LoadCombos[combo_name])
+        d = self.d(self.model.LoadCombos[combo_name])
         dyi = d[1,0]
         dyj = d[7,0]
         dzi = d[2,0]
@@ -1436,12 +1357,8 @@ class Member3D():
                 return (self.SegmentsY[lastIndex].deflection(x - self.SegmentsY[lastIndex].x1)) - dzj
 
 #%%
-    def PlotRelativeDeflection(self, Direction, combo_name='Combo 1'):
-        warnings.warn('`PlotRelativeDeflection` will be replaced with `plot_rel_deflection` in a future version of PyNite.', FutureWarning)
-        self.plot_rel_deflection(Direction, combo_name)
-
     def plot_rel_deflection(self, Direction, combo_name='Combo 1'):
-        '''
+        """
         Plots the deflection diagram for the member
         
         Parameters
@@ -1450,12 +1367,12 @@ class Member3D():
             The direction in which to plot the deflection.
         combo_name : string
             The name of the load combination to get the results for (not the combination itself).
-        '''
+        """
         
         # Segment the member if necessary
         if self.__solved_combo == None or combo_name != self.__solved_combo.name:
             self._segment_member(combo_name)
-            self.__solved_combo = self.LoadCombos[combo_name]
+            self.__solved_combo = self.model.LoadCombos[combo_name]
                 
         # Import 'pyplot' if not already done
         if Member3D.__plt is None:
@@ -1481,9 +1398,11 @@ class Member3D():
         Member3D.__plt.title('Member ' + self.name + '\n' + combo_name)
         Member3D.__plt.show()   
         
-#%%    
-    # Divides the element up into mathematically continuous segments along each axis
+#%%
     def _segment_member(self, combo_name='Combo 1'):
+        """
+        Divides the element up into mathematically continuous segments along each axis
+        """
         
         # Get the member's length and stiffness properties
         L = self.L()
@@ -1496,7 +1415,7 @@ class Member3D():
         SegmentsX = self.SegmentsX
         
         # Get the load combination to segment the member for
-        combo = self.LoadCombos[combo_name]
+        combo = self.model.LoadCombos[combo_name]
 
         # Create a list of discontinuity locations
         disconts = [0, L] # Member ends
@@ -1544,7 +1463,7 @@ class Member3D():
         
         # Get the element local end forces, local fixed end reactions, and local displacements
         f = self.f(combo_name)           # Member local end force vector
-        fer = self._fer_unc(combo_name) # Member local fixed end reaction vector
+        fer = self._fer_unc(combo_name)  # Member local fixed end reaction vector
         d = self.d(combo_name)           # Member local displacement vector
         
         # Get the local deflections and calculate the slope at the start of the member
